Installation
============

Notes on how to install


##### PyPI
To install the core package run: `pip install seaflux`.
Check that you are using the correct version of `pip`.

##### GitHub
For the most up to date version of Sea Flux, you can install directly from the online repository hosted on GitLab.

1. Clone seaflux to your local machine: `git clone https://github.com/luke-gregor/SeaFlux`
2. Change to the parent directory of SeaFlux
3. Install seaflux with `pip install -e ./SeaFlux`. This will allow changes you make locally, to be reflected when you import the package in Python
